export default api;
export type SassType = sass.types.Null | sass.types.Number | sass.types.String | sass.types.Boolean | sass.types.Color | sass.types.List | sass.types.Map;
export type JsonValue = JsonPrimitive | JsonObject | JsonValue[];
export type JsonArray = JsonValue[];
export type JsonPrimitive = string | number | boolean | null;
export type JsonObject = {
    [x: string]: JsonValue | undefined;
};
/** @type {{ 'json-encode($value, $quotes: true)': typeof encode, 'json-decode($value)': typeof decode }} */
declare const api: {
    'json-encode($value, $quotes: true)': typeof encode;
    'json-decode($value)': typeof decode;
};
import sass from "sass";
/**
 * @typedef {sass.types.Null|sass.types.Number|sass.types.String|sass.types.Boolean|sass.types.Color|sass.types.List|sass.types.Map} SassType
 */
/**
 * @typedef {JsonPrimitive | JsonObject | JsonArray} JsonValue
 * @typedef {JsonValue[]} JsonArray
 * @typedef {string | number | boolean | null} JsonPrimitive
 * @typedef {{[Key in string]?: JsonValue}} JsonObject
 */
/**
 * Encodes (`JSON.stringify`) data and returns Sass string. By default, string is quoted with single quotes so that it can be easily used in standard CSS values.
 *
 * @param {SassType}           value  Data to encode (stringify).
 * @param {sass.types.Boolean} quotes Should output string be quoted with single quotes.
 */
declare function encode(value: SassType, quotes: sass.types.Boolean): sass.types.String;
/**
 * Decodes (`JSON.parse`) string and returns one of available Sass types.
 *
 * @param {sass.types.String} value String to decode (parse).
 */
declare function decode(value: sass.types.String): sass.types.Null | sass.types.Number | sass.types.String | sass.types.Boolean<true> | sass.types.Boolean<false> | sass.types.Color | sass.types.List<sass.types.SassType> | sass.types.Map<sass.types.SassType, sass.types.SassType>;
//# sourceMappingURL=index.d.ts.map